/**
 * AWS Credentials
 */
export interface Credentials {
    /**
     * AWS access key ID
     */
    accessKeyId: string;
    /**
     * AWS secret access key
     */
    secretAccessKey: string;
    /**
     * AWS profile
     */
    profile?: string;
}
/**
 * Returns true if the provided AWS credentials are valid.
 *
 * @param credentials AWS credentials to validate
 */
export declare function getAccount(credentials: Credentials): Promise<string | undefined>;
/**
 * Get AWS credentials from environment variables or INI files.
 *
 * @param profile AWS profile to use
 */
export declare function getCredentials(profile?: string): Promise<Credentials | undefined>;
/**
 * Persist AWS credentials to .aws/credentials if they aren't already present
 *
 * @param credentials AWS credentials to persist
 */
export declare function saveLocalCredentials(credentials: any): Promise<boolean>;
