import { Command } from 'commander';
/**
 * Ness Settings
 */
export declare type NessSettings = {
    dir?: string;
    prod?: boolean;
    domain?: string;
    profile?: string;
    redirectWww?: boolean;
    csp?: string;
    indexDocument?: string;
    errorDocument?: string;
    spa?: boolean;
    verbose?: boolean;
};
/**
 * Get settings from local configuration file.
 *
 * @param entry Path to the project root. Defaults to process.cwd().
 */
export declare function getSettingsFromFile(entry?: string): Promise<NessSettings | undefined>;
/**
 * Get settings from command args.
 *
 * @param command Commander command to extract args from.
 */
export declare function getSettingsFromArgs(command: Command): Promise<NessSettings | undefined>;
/**
 * Persist settings to ./ness.json
 *
 * @param settings Settings to persist
 * @param entry Path to the project root. Defaults to process.cwd().
 */
export declare function saveSettings(settings: NessSettings, entry?: string): Promise<boolean>;
